
# Enum: DiagnosisType




URI: [ks:DiagnosisType](https://w3id.org/linkml/tests/kitchen_sink/DiagnosisType)


## Other properties

|  |  |  |
| --- | --- | --- |

## Permissible Values

| Text | Description | Meaning | Other Information |
| :--- | :---: | :---: | ---: |

